@@ -6,8 +6,8 @@ This file contains a :code:`__name__ == "__main__"` and can be run directly.
 
 import argparse
 import datetime
-import importlib
 import glob
+import importlib
 import logging
 import multiprocessing as mp
 import os
@@ -16,11 +16,12 @@ import shutil
 import subprocess
 import sys
 import traceback
-
 from typing import List
 
+from rich.progress import BarColumn, Progress, TextColumn, TimeElapsedColumn
+
+from curifactory import docker, hashing, reporting, utils
 from curifactory.manager import ArtifactManager
-from curifactory import utils, docker
 
 CONFIGURATION_FILE = "curifactory_config.json"
 
@@ -53,6 +54,11 @@ def run_experiment(  # noqa: C901 -- TODO: this does need to be broken up at som
     run_ts_override: datetime.datetime = None,
     lazy: bool = False,
     ignore_lazy: bool = False,
+    no_map: bool = False,
+    no_color: bool = False,
+    quiet: bool = False,
+    progress: bool = False,
+    plain: bool = False,
     notes: str = None,
 ):
     """The experiment entrypoint function. This executes the given experiment
@@ -115,6 +121,14 @@ def run_experiment(  # noqa: C901 -- TODO: this does need to be broken up at som
             handle pickle serialization correctly may cause errors.
         ignore_lazy (bool): Run the experiment disabling any lazy object caching/keeping everything in memory.
             This can save time when memory is less of an issue.
+        no_map (bool): Prevent pre-execution mapping of experiment records and stages. Recommended if doing
+            anything fancy with records like dynamically creating them based on results of previous records.
+            Mapping is done by running the experiment but skipping all stage execution.
+        no_color (bool): Suppress fancy colors in console output.
+        quiet (bool): Suppress all console log output.
+        progress (bool): Display fancy rich progress bars for each record.
+        plain (bool): Use normal text log output rather than rich log. Note that
+            this negates progress.
         notes (str): A git-log-like message to store in the run info for the current run. If this is an
             empty string, query the user for an input string.
 
@@ -165,12 +179,41 @@ def run_experiment(  # noqa: C901 -- TODO: this does need to be broken up at som
             run_string += " --lazy"
         if ignore_lazy:
             run_string += " --ignore-lazy"
+        if no_map:
+            run_string += " --no-map"
+        if no_color:
+            run_string += " --no-color"
+        if quiet:
+            run_string += " --quiet"
 
         # TODO: remainder of flags
 
     # NOTE: this allows a project root /params /experiments to work, but unfortunately doesn't automagically work if you have nested folders (you need to put __init__.py in each dir)
     sys.path.append(os.getcwd())
 
+    # distributed run check, automatically set parallel mode if we're not rank 0
+    # this was added because of issues with pytorch distributed compute
+    distributed_mode_detected = False
+    warn_store_full_during_distributed = False
+    if "LOCAL_RANK" in os.environ and os.getenv("LOCAL_RANK") != "0":
+        distributed_mode_detected = True
+    elif "NODE_RANK" in os.environ and os.getenv("NODE_RANK") != "0":
+        distributed_mode_detected = True
+    elif "RANK" in os.environ and os.getenv("RANK") != "0":
+        distributed_mode_detected = True
+    if distributed_mode_detected:
+        parallel_mode = True
+
+        # if we're in a distributed run, we need to make sure to _not_ do
+        # a store full on the non-rank-0 processes, otherwise each process
+        # outputs a full copy into a full store folder that isn't even labeled
+        # correctly (doesn't have run info with run num.) We throw a warning
+        # to ensure the user knows any full store caching they do (really all
+        # caching) needs to be handled by the rank 0 process.
+        if store_entire_run:
+            warn_store_full_during_distributed = True
+            store_entire_run = False
+
     # get the experiment run notes if requested
     if notes == "":
         notes_file = "temp_run_notes_content.txt"
@@ -186,7 +229,7 @@ def run_experiment(  # noqa: C901 -- TODO: this does need to be broken up at som
         os.system(f"{utils.get_editor()} {notes_file}")
 
         # get the content
-        with open(notes_file, "r") as infile:
+        with open(notes_file) as infile:
             lines = [line for line in infile.readlines() if not line.startswith("#")]
         notes = "".join(lines).strip("\n")
 
@@ -252,7 +295,10 @@ def run_experiment(  # noqa: C901 -- TODO: this does need to be broken up at som
     if log:
         log_name = mngr.get_reference_name()
         if parallel_mode:
-            log_name += f"_{str(global_args_indices[0])}"
+            if global_args_indices is not None:
+                log_name += f"_{str(global_args_indices[0])}"
+            else:
+                log_name += f"_p{str(os.getpid())}"
         log_path = os.path.join(mngr.logs_path, f"{log_name}.log")
 
         if dry:
@@ -261,9 +307,21 @@ def run_experiment(  # noqa: C901 -- TODO: this does need to be broken up at som
         level = logging.INFO
         if log_debug:
             level = logging.DEBUG
-        utils.init_logging(log_path, level, log_errors, include_process=parallel_mode)
+        utils.init_logging(
+            log_path,
+            level,
+            log_errors,
+            include_process=parallel_mode,
+            quiet=quiet,
+            no_color=no_color,
+            plain=plain,
+        )
 
     logging.info("Running experiment %s" % experiment_name)
+    if mngr.git_workdir_dirty:
+        logging.warning(
+            "Git working directory contains uncommited changes. Reproduction may not be exact."
+        )
 
     # insert an implied parameter file that is the same as the experiment file, if no parameters were explicitly listed
     if parameters_list is None or len(parameters_list) == 0:
@@ -273,6 +331,19 @@ def run_experiment(  # noqa: C901 -- TODO: this does need to be broken up at som
         )
         parameters_list = [experiment_name]
 
+    # let the user know if we detected a distributed run
+    if distributed_mode_detected:
+        logging.info(
+            "A distributed run was detected from environment variables - automatically using --parallel-mode on non-rank-0 processes."
+        )
+
+    # if the user was doing a full store distributed run, let them know the non-rank-zero processes
+    # won't be storing anything in the full store directory
+    if warn_store_full_during_distributed:
+        logging.warning(
+            "Full store was requested for a distributed run - full store has been disabled on all non-rank-zero processes to prevent data duplication. Ensure that any necessary data for a full store is handled in rank zero."
+        )
+
     # load params files
     argsets = []
     for params in parameters_list:
@@ -284,7 +355,6 @@ def run_experiment(  # noqa: C901 -- TODO: this does need to be broken up at som
             logging.debug("Trying to load params module '%s'" % param_module_string)
             param_module = importlib.import_module(param_module_string)
         except ModuleNotFoundError:
-            # TODO:
             try:
                 logging.debug(
                     "Module not found, trying '%s'" % experiment_module_string
@@ -308,7 +378,6 @@ def run_experiment(  # noqa: C901 -- TODO: this does need to be broken up at som
         # TODO: if param_argsets is not of type List, throw exception and advise
         # compute the hash of every argset and store the params
         for index, argset in enumerate(param_argsets):
-
             # if specific names requested, just grab those
             if args_names is not None:
                 if argset.name not in args_names:
@@ -319,16 +388,21 @@ def run_experiment(  # noqa: C901 -- TODO: this does need to be broken up at som
                 if index not in args_indices_resolved:
                     continue
 
-            argset.hash = utils.args_hash(
-                argset, mngr.manager_cache_path, (not dry and not parallel_mode)
+            argset.hash = hashing.args_hash(
+                argset,
+                store_in_registry=(not dry and not parallel_mode),
+                registry_path=mngr.manager_cache_path,
             )
             mngr.experiment_args[params].append((argset.name, argset.hash))
             # TODO: (01/24/2022) I have no idea what the point of this args_hash is...
             # it's not storing anything, and args_hash has no side-effects, so unclear
             # on why this matters.
+            # NOTE: (3/5/2023) is it just so that the hash is computed and stored
+            # on the args? Unclear exactly why that's necessary but that is technically
+            # a side-effect
             if store_entire_run:
-                utils.args_hash(
-                    argset, None, False
+                hashing.args_hash(
+                    argset, store_in_registry=False
                 )  # don't try to store because get_run_output_path does not exist yet
             argsets_to_add.append(argset)
 
@@ -351,8 +425,10 @@ def run_experiment(  # noqa: C901 -- TODO: this does need to be broken up at som
     # TODO: is this already being done in manager get_path?
     if store_entire_run:
         for argset in argsets:
-            utils.args_hash(
-                argset, mngr.get_run_output_path(), (not dry and not parallel_mode)
+            hashing.args_hash(
+                argset,
+                store_in_registry=(not dry and not parallel_mode),
+                registry_path=mngr.get_run_output_path(),
             )
 
     # note that nothing is being cached or stored
@@ -430,6 +506,11 @@ def run_experiment(  # noqa: C901 -- TODO: this does need to be broken up at som
                     mngr.run_timestamp,
                     lazy,
                     ignore_lazy,
+                    no_map,
+                    no_color,
+                    quiet,
+                    progress,
+                    plain,
                 ),
             )
             logging.info(
@@ -472,12 +553,66 @@ def run_experiment(  # noqa: C901 -- TODO: this does need to be broken up at som
         f"{mngr.config['experiments_module_name']}.{experiment_name}"
     )
     try:
+        # run experiment mapping and set up progress bars
+        if not parallel_mode and not no_map:
+            logging.info("Pre-mapping stages and records")
+            mngr.map_mode = True
+            experiment_module.run(argsets, mngr)
+            mngr.map_mode = False
+            logging.debug("Constructing record map")
+            mngr.map_records()
+            logging.info("Stage map collected")
+
+            # create a (rich) progress bar and the associated tasks for each
+            # mapped record.
+            if progress:
+                mngr.map_progress = Progress(
+                    TextColumn("{task.completed}/{task.total}"),
+                    BarColumn(bar_width=30, pulse_style="cyan"),
+                    TextColumn("[progress.description]{task.description}"),
+                    TimeElapsedColumn(),
+                    TextColumn("{task.fields[name]}"),
+                )
+                for i, record in enumerate(mngr.map):
+                    name = record.args.name if record.args is not None else "None"
+                    if record.is_aggregate:
+                        name += " (aggregate)"
+                    hash_big = record.get_hash()
+                    hash_cut = record.get_hash()[:8]
+                    # logging.debug("LENGTH %s" % len(record.stages))
+                    taskid = mngr.map_progress.add_task(
+                        f"Record {i}, args: {name}, hash: {hash_cut}",
+                        total=len(record.stages),
+                        start=False,
+                        visible=True,
+                        name="",
+                        hash_big=hash_big,
+                        hash_cut=hash_cut,
+                    )
+                    record.taskid = taskid
+                overalltaskid = mngr.map_progress.add_task(
+                    f"Total ({mngr.get_reference_name()})",
+                    total=len(mngr.map),
+                    visible=True,
+                    name="",
+                    hash_big="",
+                    hash_cut="",
+                )
+                mngr.map_progress_overall_task_id = overalltaskid
+
+                mngr.map_progress.start()
+
         results = experiment_module.run(argsets, mngr)
 
+        if not parallel_mode and not no_map and progress:
+            mngr.map_progress.stop()
+
         # don't change status if we logged an error from a parallel process
         if not mngr.error_thrown:
             mngr.status = "complete"
     except Exception as e:
+        if not parallel_mode and not no_map and progress:
+            mngr.map_progress.stop()
         results = None
         error_thrown = True
         logging.error(e)
@@ -508,8 +643,9 @@ def run_experiment(  # noqa: C901 -- TODO: this does need to be broken up at som
         # TODO details file for any meta information (if it errored or not)
 
     if build_notebook and not dry and not parallel_mode:
+        notebook_loc = os.path.join(mngr.notebooks_path, "experiments")
         try:
-            os.mkdir("notebooks/experiments")
+            os.makedirs(notebook_loc, exist_ok=True)
         # TODO: Handle exceptions better
         except:  # noqa: E722
             pass
@@ -518,7 +654,7 @@ def run_experiment(  # noqa: C901 -- TODO: this does need to be broken up at som
             parameters_list,
             argsets,
             mngr,
-            path="notebooks/experiments/" + mngr.get_reference_name(),
+            path=os.path.join(notebook_loc, mngr.get_reference_name()),
             use_global_cache=None,
             errored=error_thrown,
         )
@@ -749,7 +885,7 @@ def regex_lister(path, regex):
     for filename in os.scandir(path):
         # iterate every python file
         if filename.path.endswith(".py"):
-            with open(filename.path, "r") as infile:
+            with open(filename.path) as infile:
                 lines = infile.readlines()
                 # check for a run() method
                 results = [re.findall(regex, line) for line in lines]
@@ -814,133 +950,20 @@ def main():
     """'Main' command line entrypoint, parses command line flags and makes the
     appropriate :code:`run_experiment()` call."""
     parser = argparse.ArgumentParser(
-        epilog="Example:\n\texperiment my_experiment -p some_params1 -p some_params2"
+        description="Run a given curifactory experiment with specified parameters.",
+        formatter_class=argparse.RawDescriptionHelpFormatter,
+        epilog="""
+Examples:
+    experiment my_experiment -p some_params1 -p some_params2
+    experiment my_experiment_with_params
+    experiment my_experiment_with_params --overwrite
+
+    experiment ls  # lists all available experiments and parameters
+    experiment reports --port 8000 --host 0.0.0.0
+""",
     )
     parser.add_argument("experiment_name")
-    parser.add_argument(
-        "-p",
-        dest="parameters_name",
-        # required=True,
-        action="append",
-        help="The name of a parameters python file. Does not need to include path or .py. You can specify multiple -p arguments to run all parameters",
-    )
-    parser.add_argument(
-        "--names",
-        dest="args_name",
-        action="append",
-        help="The name of a specific argset within one of the specified parameters files. Using this will run only the specified argset(s).",
-    )
-    parser.add_argument(
-        "--indices",
-        dest="args_index",
-        action="append",
-        help="A single or range of indices of argsets to use within the specified parameters files. Note that specifying this will run those indices from all specified parameters files. Specify ranges like '1-5'.",
-    )
-    parser.add_argument(
-        "--global-indices",
-        dest="global_indices",
-        action="append",
-        help="A single or range of indices of argsets to use out of the total list of argsets passed to the experiment.",
-    )
-    parser.add_argument(
-        "--parallel",
-        dest="parallel",
-        default=None,
-        help="Divide the parameters among n subprocesses in order to cache intermediate results in parallel, and then re-run in original process with cached data.",
-    )
-    parser.add_argument(
-        "--parallel-mode",
-        dest="parallel_mode",
-        action="store_true",
-        help="Runs an experiment and caches intermediate values but does not report or touch experiment store and parameter registry. Note that using this flag manually is not equivalent to running an experiment with the --parallel flag, as file locks don't get used when calling this manually, potentially creating race conditions.",
-    )
-    parser.add_argument(
-        "--no-log",
-        dest="no_log",
-        action="store_true",
-        help="Specify this flag to not store the log.",
-    )
-    parser.add_argument(
-        "--overwrite",
-        dest="overwrite_override",
-        action="store_true",
-        help="Overwrite current cached objects",
-    )
-    parser.add_argument(
-        "--overwrite-stage",
-        dest="overwrite_stages",
-        action="append",
-        help="Names of specific stages to overwrite",
-    )
-    parser.add_argument(
-        "-s",
-        "--store-full",
-        dest="store_full",
-        action="store_true",
-        help="Store a copy of environment information and every cached object in a folder named with the experiment reference.",
-    )
-    parser.add_argument(
-        "-c",
-        "--cache",
-        dest="cache_dir",
-        help="Specify a different directory to use as the cache.",
-    )
-    parser.add_argument(
-        "-v",
-        "--verbose",
-        dest="verbose",
-        action="store_true",
-        help="Log at debug level.",
-    )
-    parser.add_argument(
-        "--dry",
-        dest="dry",
-        action="store_true",
-        help="Do a dry run: suppresses writing any cached objects and modifying stores.",
-    )
-    parser.add_argument(
-        "--dry-cache",
-        dest="dry_cache",
-        action="store_true",
-        help="Do a dry cache run: this still modifies stores and runs reports but does not write anything into the cache. This is recommended when running an experiment with a cache directory from --store-full.",
-    )
-    parser.add_argument(
-        "--log-errors",
-        dest="log_errors",
-        action="store_true",
-        help="Include errors and stack traces in output logs. NOTE: this redirects stderr - output from libraries like tqdm will be logged as well.",
-    )
-    parser.add_argument(
-        "-n",
-        "--name",
-        dest="name",
-        default=None,
-        help="Specify a custom name to use for caching rather than the experiment name. This can be useful if multiple similar experiments can use the same cached objects. Note that this does not change the reference name.",
-    )
-    parser.add_argument(
-        "--docker",
-        dest="docker",
-        action="store_true",
-        help="Generates a docker image with the used cached files and a current copy of the codebase.",
-    )
-    parser.add_argument(
-        "--notebook",
-        dest="notebook",
-        action="store_true",
-        help="Generates a jupyter notebook to explore the results.",
-    )
-    parser.add_argument(
-        "--lazy",
-        dest="lazy",
-        action="store_true",
-        help="Attempts to lazy-cache all outputs from all stages. WARNING: if cachers are not specified throughout the stages, PickleCachers will be inserted. As pickle serialization does not work on some complex objects, this may fail. Specify valid cachers for all stage outputs to mitigate this.",
-    )
-    parser.add_argument(
-        "--ignore-lazy",
-        dest="ignore_lazy",
-        action="store_true",
-        help="Run the experiment without any lazy object caching, this can save time when memory is less of an issue.",
-    )
+
     parser.add_argument(
         "--notes",
         nargs="?",  # this is how we allow it to be specified either as a flag or with a value
@@ -949,21 +972,208 @@ def main():
         default=False,
         help="Associate some notes with this run. You can either directly specify a string to this flag, or leave it blank to open a notes file in your editor.",
     )
-    parser.add_argument(
+
+    parameters_group = parser.add_argument_group(
+        "Parameterization",
+        "Choose which parameter files and which parameter sets to use.",
+    )
+    outputs_group = parser.add_argument_group(
+        "Outputs", "Control what gets created from an experiment run."
+    )
+    caching_group = parser.add_argument_group(
+        "Caching", "Configure cache usage (re-entrancy) and lazy artifacts."
+    )
+    display_group = parser.add_argument_group(
+        "Display", "Configure console output during experiment execution."
+    )
+    parallel_group = parser.add_argument_group("Parallel execution")
+    reports_group = parser.add_argument_group(
+        "Reports", "Arguments for use with 'experiment reports'"
+    )
+
+    # ---- PARAMETERS ----
+    parameters_group.add_argument(
+        "-p",
+        dest="parameters_name",
+        action="append",
+        help="The name of a parameters python file. Does not need to include path or .py. You can specify multiple -p arguments to run all parameters",
+    )
+    parameters_group.add_argument(
+        "--names",
+        dest="args_name",
+        action="append",
+        help="The name of a specific argset within one of the specified parameters files. Using this will run only the specified argset(s).",
+    )
+    parameters_group.add_argument(
+        "--indices",
+        dest="args_index",
+        action="append",
+        help="A single or range of indices of argsets to use within the specified parameters files. Note that specifying this will run those indices from all specified parameters files. Specify ranges like '1-5'.",
+    )
+    parameters_group.add_argument(
+        "--global-indices",
+        dest="global_indices",
+        action="append",
+        help="A single or range of indices of argsets to use out of the total list of argsets passed to the experiment.",
+    )
+
+    # ---- OUTPUTS ----
+    outputs_group.add_argument(
+        "--notebook",
+        dest="notebook",
+        action="store_true",
+        help="Generates a jupyter notebook to explore the results.",
+    )
+    outputs_group.add_argument(
+        "--docker",
+        dest="docker",
+        action="store_true",
+        help="Generates a docker image with the used cached files and a current copy of the codebase.",
+    )
+    outputs_group.add_argument(
+        "--no-log",
+        dest="no_log",
+        action="store_true",
+        help="Specify this flag to not store the log.",
+    )
+    outputs_group.add_argument(
+        "--dry",
+        dest="dry",
+        action="store_true",
+        help="Do a dry run: suppresses writing any cached objects and modifying stores.",
+    )
+    outputs_group.add_argument(
+        "--log-errors",
+        dest="log_errors",
+        action="store_true",
+        help="Include errors and stack traces in output logs. NOTE: this redirects stderr - output from libraries like tqdm will be logged as well.",
+    )
+
+    # ---- CACHING ----
+    caching_group.add_argument(
+        "-c",
+        "--cache",
+        dest="cache_dir",
+        help="Specify a different directory to use as the cache.",
+    )
+    caching_group.add_argument(
+        "-s",
+        "--store-full",
+        dest="store_full",
+        action="store_true",
+        help="Store a copy of environment information and every cached object in a folder named with the experiment reference.",
+    )
+    caching_group.add_argument(
+        "--overwrite",
+        dest="overwrite_override",
+        action="store_true",
+        help="Overwrite current cached objects",
+    )
+    caching_group.add_argument(
+        "--overwrite-stage",
+        dest="overwrite_stages",
+        action="append",
+        help="Names of specific stages to overwrite",
+    )
+    caching_group.add_argument(
+        "--dry-cache",
+        dest="dry_cache",
+        action="store_true",
+        help="Do a dry cache run: this still modifies stores and runs reports but does not write anything into the cache. This is recommended when running an experiment with a cache directory from --store-full.",
+    )
+    caching_group.add_argument(
+        "-n",
+        "--name",
+        dest="name",
+        default=None,
+        help="Specify a custom name to use for caching rather than the experiment name. This can be useful if multiple similar experiments can use the same cached objects. Note that this does not change the reference name.",
+    )
+    caching_group.add_argument(
+        "--lazy",
+        dest="lazy",
+        action="store_true",
+        help="Attempts to lazy-cache all outputs from all stages. WARNING: if cachers are not specified throughout the stages, PickleCachers will be inserted. As pickle serialization does not work on some complex objects, this may fail. Specify valid cachers for all stage outputs to mitigate this.",
+    )
+    caching_group.add_argument(
+        "--ignore-lazy",
+        dest="ignore_lazy",
+        action="store_true",
+        help="Run the experiment without any lazy object caching, this can save time when memory is less of an issue.",
+    )
+
+    # ---- DISPLAY ----
+    display_group.add_argument(
+        "-v",
+        "--verbose",
+        dest="verbose",
+        action="store_true",
+        help="Log at debug level.",
+    )
+    display_group.add_argument(
+        "--no-map",
+        dest="no_map",
+        action="store_true",
+        help="Specifying will prevent the pre - execution mapping of the experiment records and stages. If doing non - DAG or creating dynamic records based on results of previous ones (where the map will be incorrect) use this flag.",
+    )
+    display_group.add_argument(
+        "--quiet",
+        dest="quiet",
+        action="store_true",
+        help="Suppress all log output to console.",
+    )
+    display_group.add_argument(
+        "--no-color", dest="no_color", action="store_true", help="Less fancy colors."
+    )
+    display_group.add_argument(
+        "--progress",
+        dest="progress",
+        action="store_true",
+        help="Display fancy progress bars! Note that this uses rich live and can break existing tqdm progress bars and other things.",
+    )
+    display_group.add_argument(
+        "--plain",
+        dest="plain",
+        action="store_true",
+        help="Print normal logging rather than rich colored logs. This will output the exact same text printed into the file log.",
+    )
+
+    # ---- PARALLEL ----
+    parallel_group.add_argument(
+        "--parallel",
+        dest="parallel",
+        default=None,
+        help="Divide the parameters among n subprocesses in order to cache intermediate results in parallel, and then re-run in original process with cached data.",
+    )
+    parallel_group.add_argument(
+        "--parallel-mode",
+        dest="parallel_mode",
+        action="store_true",
+        help="Runs an experiment and caches intermediate values but does not report or touch experiment store and parameter registry. Note that using this flag manually is not equivalent to running an experiment with the --parallel flag, as file locks don't get used when calling this manually, potentially creating race conditions.",
+    )
+
+    # ---- REPORTS ----
+    reports_group.add_argument(
         "--port",
         dest="port",
         default=8080,
         help="Only used for 'experiment reports', specifies which port to run the simple server on.",
     )
-    parser.add_argument(
+    reports_group.add_argument(
         "--host",
         dest="host",
         default="127.0.0.1",
         help="Only used for 'experiment reports', specifies which hostname to run the simple server on.",
     )
+    reports_group.add_argument(
+        "--update",
+        dest="update",
+        action="store_true",
+        help="Only used for 'experiment reports', updates the report index with all exisiting reports in the reports file. This is to handle if you pull in reports from other machines.",
+    )
 
     # fix any missing quotes in run line
     command_parts = sys.argv[1:]
+
     fixed_parts = []
     for index, part in enumerate(command_parts):
         if " " in part and not part.startswith('"') and not part.endswith('"'):
@@ -983,7 +1193,6 @@ def main():
     params_list = args.parameters_name
 
     if args.experiment_name == "ls":
-
         sys.path.append(os.getcwd())
         print("EXPERIMENTS:")
         for experiment in list_experiments():
@@ -994,6 +1203,13 @@ def main():
         exit()
 
     elif args.experiment_name == "reports":
+        if args.update:
+            config = utils.get_configuration()
+            utils.init_logging(None)
+            reporting.update_report_index(
+                config["experiments_module_name"], config["reports_path"]
+            )
+            exit()
         os.chdir("reports")
         utils.run_command(
             ["python", "-m", "http.server", str(args.port), "--bind", args.host]
@@ -1001,9 +1217,8 @@ def main():
         os.chdir("..")
         exit()
 
-    # todo: verify names exist
-    # todo: ensure folders exist (logs)
-    # todo: add cache overwrite option
+    # TODO: verify names exist
+    # TODO: ensure folders exist (logs)
 
     log = True
     if args.no_log:
@@ -1039,6 +1254,11 @@ def main():
         parallel_mode=args.parallel_mode,
         lazy=args.lazy,
         ignore_lazy=args.ignore_lazy,
+        no_map=args.no_map,
+        no_color=args.no_color,
+        quiet=args.quiet,
+        progress=args.progress,
+        plain=args.plain,
         notes=args.notes,
     )
 
