@@ -5,7 +5,6 @@ This is handled through a base :code:`Reportable` class, and each reporter class
 extends it.
 """
 
-from dataclasses import asdict
 import datetime
 import json
 import logging
@@ -15,13 +14,11 @@ from typing import List
 
 import matplotlib.pyplot as plt
 import numpy as np
-
+import pandas as pd
 from graphviz import Digraph
 from graphviz.backend import ExecutableNotFound
-import pandas as pd
-
-from curifactory import utils
 
+from curifactory import hashing, utils
 
 COLORS = [
     "darkseagreen2",  # #b4eeb4
@@ -331,7 +328,9 @@ def render_report_head(manager) -> List[str]:
     ]
 
 
-def render_report_info_block(manager) -> List[str]:
+def render_report_info_block(  # noqa: C901 -- TODO: yeaaaaah break it up at some point
+    manager,
+) -> List[str]:
     """Generate the header and block of metadata at the top of the report."""
 
     html_lines = []
@@ -353,6 +352,11 @@ def render_report_info_block(manager) -> List[str]:
     if manager.interactive:
         status_line += " - (interactive session)"
 
+    commit_line = "Git commit: "
+    if manager.git_workdir_dirty:
+        commit_line += "<span style='color: darkorange'><b>*</b></span>"
+    commit_line += f"{manager.git_commit_hash}"
+
     html_lines.append(
         f"<h1 id='title'>Report: {manager.experiment_name} - {manager.experiment_run_number}</h1>"
     )
@@ -365,12 +369,13 @@ def render_report_info_block(manager) -> List[str]:
             f"Reference: <b>{manager.get_reference_name()}</b></br>",
             f"Hostname: <b>{manager.hostname}</b></br>",
             f"Run status: {status_line}</br>",
-            f"Git commit: {manager.git_commit_hash}</br>",
+            f"{commit_line}</br>",
             f"Params files: {str(manager.experiment_args_file_list)}</br></p>",
-            "<ul>",
         ]
     )
+
     # output the list of parameters used and assoc hashes
+    html_lines.append("<ul>")
     handled_hashes = []
     for key in manager.experiment_args:
         html_lines.append(f"<li>{key} <ul>")
@@ -392,6 +397,11 @@ def render_report_info_block(manager) -> List[str]:
 
     html_lines.append("</ul></div>")
 
+    if manager.git_workdir_dirty:
+        html_lines.append(
+            "<p><span style='color: orange;'><b>*WARNING - </b></span>Uncommited changes.</p>"
+        )
+
     if manager.status == "LIVE":
         # TODO: (37/26/2022) allow suppression if notebook=true passed so can render in notebook without error?
         html_lines.append(
@@ -553,10 +563,7 @@ def render_report_argset_dump(manager) -> List[str]:
             # make html-safe
             return str(x).replace("<", "&lt;").replace(">", "&gt;")
 
-        argset_data = asdict(argset)
-        del argset_data["name"]
-        del argset_data["overwrite"]
-        del argset_data["hash"]
+        argset_data = hashing.parameters_string_hash_representation(argset)
         html_lines.append(json.dumps(argset_data, indent=2, default=stringify))
         html_lines.append("</pre>")
 
@@ -733,7 +740,7 @@ def update_report_index(experiments_path, reports_root_dir):
             continue
 
         if os.path.exists(f"{full_filename}/run_info.json"):
-            with open(f"{full_filename}/run_info.json", "r") as infile:
+            with open(f"{full_filename}/run_info.json") as infile:
                 info = json.load(infile)
 
                 info["order_timestamp"] = datetime.datetime.strptime(
@@ -747,9 +754,7 @@ def update_report_index(experiments_path, reports_root_dir):
                     # try to get comment on experiment
                     comment = ""
                     try:
-                        with open(
-                            f"{experiments_path}/{experiment_name}.py", "r"
-                        ) as infile:
+                        with open(f"{experiments_path}/{experiment_name}.py") as infile:
                             lines = infile.readlines()
                             comment = utils.get_py_opening_comment(lines)
                     except:  # noqa: E722 -- there's not really any need to handle this, either we get the comment or we don't.
@@ -985,7 +990,11 @@ def _get_run_index_line(run):
     elif run["status"] == "LIVE":
         desc_line += "<span style='background-color: cyan'>&nbsp;&nbsp;</span>"
 
-    desc_line += f" <a href='{run['reference']}/index.html'>{run['reference']}</a> "
+    desc_line += f" <a href='{run['reference']}/index.html'>{run['reference']}</a>"
+
+    if "workdir_dirty" in run and run["workdir_dirty"]:
+        desc_line += "<span style='color: orange'><b>*</b></span>"
+    desc_line += " "
 
     if "hostname" in run:
         desc_line += f"[{run['hostname']}] "
